pub enum PipeValue {
Bytes(Vec<u8>),
Context(Context),
}Expand description
Value flowing through a pipe between commands within a pipeline.
Variants
Bytes(Vec<u8>)
Raw bytes from a non-optional command’s stdout (or stdout+stderr for |&).
Context(Context)
Accumulated context from a chain of optional commands, ready to be serialized to JSON and passed to the terminal non-optional command.