pub struct Pipeline {
pub commands: Vec<Command>,
pub operator: Option<Op>,
}Expand description
A sequence of Commands connected by | / |& operators within one logical unit.
operator indicates how this pipeline connects to the next one in the Program:
Some(Op::And)— next pipeline runs only if this one succeeds (&&)Some(Op::Or)— next pipeline runs only if this one fails (||)None— this is the last pipeline
Fields
commands: Vec<Command>operator: Option<Op>Trait Implementations
impl StructuralPartialEq for Pipeline