lex

Function lex 

pub fn lex(input: &str) -> Result<Vec<Token>, ParseError>
Tokenize input, splitting on whitespace but respecting balanced parentheses.

Content inside (...) is kept as a single token even if it contains spaces. This allows /echo(hello world) to remain one token.