Skip to main contentModule executor
Source - CommandOutput
- The output of running a single command via
CommandRunner. - Context
- Accumulated context passed through a chain of optional commands.
- Executor
- Orchestration engine that walks a
Program AST and applies shell-like
execution semantics.
- ExecutionError
- Errors that can occur during execution.
- PipeValue
- Value flowing through a pipe between commands within a pipeline.
- CommandRunner
- Port: dispatches a single slash command and returns its output.
- Execute
- Port: runs a complete parsed
Program and returns the final output, if any.