pub struct Context {
pub values: HashMap<String, Option<String>>,
}Expand description
Accumulated context passed through a chain of optional commands.
Each entry maps the command name to its string output (None if the command
produced no output). The context is serialized to JSON and passed as the
stdin input to the first non-optional command that terminates the chain.
Fields
values: HashMap<String, Option<String>>Implementations